==> gimp-gtk3-port_16_07_03.tar.xz: gimp-gtk3-port/app/tools/gimpcolorizetool.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_COLORIZE_TOOL_H__
#define __GIMP_COLORIZE_TOOL_H__


#include "gimpimagemaptool.h"


#define GIMP_TYPE_COLORIZE_TOOL            (gimp_colorize_tool_get_type ())
#define GIMP_COLORIZE_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_COLORIZE_TOOL, GimpColorizeTool))
#define GIMP_COLORIZE_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_COLORIZE_TOOL, GimpColorizeToolClass))
#define GIMP_IS_COLORIZE_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_COLORIZE_TOOL))
#define GIMP_IS_COLORIZE_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_COLORIZE_TOOL))
#define GIMP_COLORIZE_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_COLORIZE_TOOL, GimpColorizeToolClass))


typedef struct _GimpColorizeTool      GimpColorizeTool;
typedef struct _GimpColorizeToolClass GimpColorizeToolClass;

struct _GimpColorizeTool
{
  GimpImageMapTool  parent_instance;
};

struct _GimpColorizeToolClass
{
  GimpImageMapToolClass  parent_class;
};


void    gimp_colorize_tool_register (GimpToolRegisterCallback  callback,
                                     gpointer                  data);

GType   gimp_colorize_tool_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_COLORIZE_TOOL_H__  */

==> gimp-gtk3-port_17_04_16.tar.xz: gimp-gtk3-port/app/tools/gimpcolorizetool.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_COLORIZE_TOOL_H__
#define __GIMP_COLORIZE_TOOL_H__


#include "gimpfiltertool.h"


#define GIMP_TYPE_COLORIZE_TOOL            (gimp_colorize_tool_get_type ())
#define GIMP_COLORIZE_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_COLORIZE_TOOL, GimpColorizeTool))
#define GIMP_COLORIZE_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_COLORIZE_TOOL, GimpColorizeToolClass))
#define GIMP_IS_COLORIZE_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_COLORIZE_TOOL))
#define GIMP_IS_COLORIZE_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_COLORIZE_TOOL))
#define GIMP_COLORIZE_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_COLORIZE_TOOL, GimpColorizeToolClass))


typedef struct _GimpColorizeTool      GimpColorizeTool;
typedef struct _GimpColorizeToolClass GimpColorizeToolClass;

struct _GimpColorizeTool
{
  GimpFilterTool  parent_instance;
};

struct _GimpColorizeToolClass
{
  GimpFilterToolClass  parent_class;
};


void    gimp_colorize_tool_register (GimpToolRegisterCallback  callback,
                                     gpointer                  data);

GType   gimp_colorize_tool_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_COLORIZE_TOOL_H__  */
